Enum Nspriv
#[repr(u8)]pub enum Nspriv {
B0x0 = 0,
B0x1 = 1,
}Variants
B0x0 = 0
Read and write to RCC non-secure functions can be done by privileged or unprivileged access.
B0x1 = 1
Read and write to RCC non-secure functions can be done by privileged access only
Implementations